@@ -69,123 +69,112 @@ describe 'sahara' do
 
   end
 
-  shared_examples_for 'sahara rpc_backend' do
-    context 'with rabbit rpc' do
+  shared_examples_for 'sahara rpc' do
+
+    context 'when defaults with rabbit pass specified' do
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true) }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>') }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>') }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
+       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
+    end
+
+    context 'when passing params' do
       before do
-        params.merge!({ :rpc_backend => 'rabbit' })
-      end
-      it { is_expected.to contain_sahara_config('DEFAULT/rpc_backend').with_value('rabbit') }
-
-      context 'when defaults with rabbit pass specified' do
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true) }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
+        params.merge!({
+          :rabbit_password            => 'pass',
+          :rabbit_userid              => 'guest2',
+          :rabbit_host                => 'localhost2',
+          :rabbit_port                => '5673',
+          :rabbit_ha_queues           => 'true',
+          :amqp_durable_queues        => 'true',
+          :kombu_reconnect_delay      => '1.0',
+          :kombu_compression          => 'gzip',
+          :kombu_failover_strategy    => 'round-robin',
+        })
       end
 
-      context 'when passing params' do
-        before do
-          params.merge!({
-            :rabbit_password            => 'pass',
-            :rabbit_userid              => 'guest2',
-            :rabbit_host                => 'localhost2',
-            :rabbit_port                => '5673',
-            :rabbit_ha_queues           => 'true',
-            :amqp_durable_queues        => 'true',
-            :kombu_reconnect_delay      => '1.0',
-            :kombu_compression          => 'gzip',
-            :kombu_failover_strategy    => 'round-robin',
-          })
-        end
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest2') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_password').with_value('pass').with_secret(true) }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('localhost2') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('5673') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('1.0') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('round-robin') }
+    end
 
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest2') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_password').with_value('pass').with_secret(true) }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('localhost2') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('5673') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('1.0') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('round-robin') }
-      end
-
-      context 'with rabbit ssl cert parameters' do
-        before do
-          params.merge!({
-            :rabbit_use_ssl     => true,
-            :kombu_ssl_ca_certs => '/etc/ca.cert',
-            :kombu_ssl_certfile => '/etc/certfile',
-            :kombu_ssl_keyfile  => '/etc/key',
-            :kombu_ssl_version  => 'TLSv1',
-          })
-        end
-        it { is_expected.to contain_oslo__messaging__rabbit('sahara_config').with(
+    context 'with rabbit ssl cert parameters' do
+      before do
+        params.merge!({
           :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
           :kombu_ssl_version  => 'TLSv1',
-        )}
+        })
       end
+      it { is_expected.to contain_oslo__messaging__rabbit('sahara_config').with(
+        :rabbit_use_ssl     => true,
+        :kombu_ssl_ca_certs => '/etc/ca.cert',
+        :kombu_ssl_certfile => '/etc/certfile',
+        :kombu_ssl_keyfile  => '/etc/key',
+        :kombu_ssl_version  => 'TLSv1',
+      )}
+    end
 
-      context 'with rabbit ssl disabled' do
-        before do
-          params.merge!({
-            :rabbit_use_ssl     => false,
-          })
-        end
-
-        it { is_expected.to contain_oslo__messaging__rabbit('sahara_config').with(
+    context 'with rabbit ssl disabled' do
+      before do
+        params.merge!({
           :rabbit_use_ssl     => false,
-        )}
+        })
       end
 
-      context 'when passing params for single rabbit host' do
-        before do
-          params.merge!({
-            :rabbit_password  => 'pass',
-            :rabbit_userid    => 'guest2',
-            :rabbit_host      => 'localhost2',
-            :rabbit_port      => '5673',
-            :rabbit_ha_queues => true,
-          })
-        end
+      it { is_expected.to contain_oslo__messaging__rabbit('sahara_config').with(
+        :rabbit_use_ssl     => false,
+      )}
+    end
 
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest2') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('localhost2') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('5673') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
+    context 'when passing params for single rabbit host' do
+      before do
+        params.merge!({
+          :rabbit_password  => 'pass',
+          :rabbit_userid    => 'guest2',
+          :rabbit_host      => 'localhost2',
+          :rabbit_port      => '5673',
+          :rabbit_ha_queues => true,
+        })
       end
 
-      context 'when passing params for multiple rabbit hosts' do
-        before do
-          params.merge!({
-            :rabbit_password => 'pass',
-            :rabbit_userid   => 'guest3',
-            :rabbit_hosts    => ['nonlocalhost3:5673', 'nonlocalhost4:5673']
-          })
-        end
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest2') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('localhost2') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('5673') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
+    end
 
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest3') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('nonlocalhost3:5673,nonlocalhost4:5673') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
+    context 'when passing params for multiple rabbit hosts' do
+      before do
+        params.merge!({
+          :rabbit_password => 'pass',
+          :rabbit_userid   => 'guest3',
+          :rabbit_hosts    => ['nonlocalhost3:5673', 'nonlocalhost4:5673']
+        })
       end
+
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest3') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('nonlocalhost3:5673,nonlocalhost4:5673') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with zmq rpc' do
-      before do
-        params.merge!({ :rpc_backend => 'zmq' })
-      end
-
-      it { is_expected.to contain_sahara_config('DEFAULT/rpc_backend').with_value('zmq') }
 
       context 'with default params' do
         it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_bind_address').with_value('<SERVICE DEFAULT>') }
@@ -202,7 +191,6 @@ describe 'sahara' do
             :zeromq_bind_address => '*',
             :zeromq_host         => 'localhost',
             :cast_timeout        => '30',
-            :rpc_backend         => 'zmq',
           })
         end
 
@@ -213,9 +201,6 @@ describe 'sahara' do
     end
 
     context 'with amqp rpc' do
-      before do
-        params.merge!({ :rpc_backend => 'amqp' })
-      end
 
       context 'with default parameters' do
         it { is_expected.to contain_sahara_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -312,7 +297,7 @@ describe 'sahara' do
       it_configures 'sahara'
       it_configures 'sahara config'
       it_configures 'sahara ssl'
-      it_configures 'sahara rpc_backend'
+      it_configures 'sahara rpc'
     end
   end
 
